searchNodes=[{"doc":"Used to trace units of work and send the information to Honeycomb. Installation Adding the library to your mix.exs as a dependency should suffice: def deps ( ) do [ { :honeylixir_tracing , &quot;~&gt; 0.2.0&quot; } ] end This is the main entrypoint for this package, used to trace units of work by wrapping them in a function and report the duration as well as its relation to parent work. Configuration All of the required configuration for this package depends on configuration set for the Honeylixir project, the underlying library used for sending the data. The absolute minimum configuration required is to set the team_writekey and dataset fields: config :honeylixir , dataset : &quot;your-dataset-name&quot; , team_writekey : &quot;your-writekey&quot; In addition, optional fields available for this package are as follows: Name Type Description Default :span_ttl_sec integer How long an inactive span should remain in the ets table, in seconds, in case something has gone wrong 300 :reaper_interval_sec integer How frequently the HoneylixirTracing.Reaper should run to cleanup the ets table of orphaned spans 60 Usage Basic usage is to wrap any unit of work in a HoneylixirTracing.span call. Let's say you had the following module in your application already: defmodule TestModule do def cool_work ( arg1 , arg2 ) do arg1 + arg2 end end If you wanted to trace this function, you could do: defmodule TestModule do def cool_work ( arg1 , arg2 ) do span ( &quot;TestModule.cool_work/2&quot; , %{ &quot;arg1&quot; =&gt; arg1 , &quot;arg2&quot; =&gt; arg2 } , fn -&gt; arg1 + arg2 end ) end end Another option is to wrap the business work in a private function and invoke that in the span function: defmodule TestModule do def cool_work ( arg1 , arg2 ) do span ( &quot;TestModule.cool_work/2&quot; , %{ &quot;arg1&quot; =&gt; arg1 , &quot;arg2&quot; =&gt; arg2 } , fn -&gt; do_cool_work ( arg1 , arg2 ) end ) end defp do_cool_work ( arg1 , arg ) do arg1 + arg2 end end In both cases, the return value remains the same. The result of any span ( span/2 , span/3 , span/4 ) calls is the result of whatever function is passed in as the work. Cross-Process traces Given this is Elixir running on Erlang, it's quite possible a GenServer or some other Process-based design will appear in your system. If this is the case, there are a couple of rough recommendations on how to ensure predictable tracing data: For synchronous work, add a final argument of ctx , which is a HoneylixirTracing.Propagation.t/0 struct, to the callback. This should not be accepted by the Client API but instead built for the user directly and passed to the Server. In the callback, use that as the first argument to a HoneylixirTracing.span/4 call which wraps your work. For asynchronous work, do not start a span from a context passed in. Asynchronous work is akin to background work done by a web application, meaning that one would consider them linked spans rather than child spans. You can use the underlying Honeylixir library to send these events along. Utility functions may be provided in the future to help with this. A small example for doing this within an application for synchronous work can be found in the cross_process_example project in the examples directory. Adding data to the current span If you want to add fields to your spans after initialization or invocation, you can use add_field_data/1 to add data. add_field_data/1 accepts a Map of strings to any encodable entity (just like span/2 and the underlying Honeylixir.Event ) and modifies the currently active span with the information. If no span is active, this function does nothing. defmodule TestModule do def some_work ( ) do span ( &quot;TestModule.some_work/0&quot; , fn -&gt; result = CoolModule . do_something_else ( ) HoneylixirTracing . add_field_data ( %{ &quot;cool_mod.result&quot; =&gt; result } ) end ) end end The Reaper The Reaper module handles cleaning up the ets table used to store state. Two pieces of configuration relate to this: span_ttl_sec -&gt; how long a span should remain in the ets table :reaper_interval_sec -&gt; how frequently the Reaper should run in seconds If the Span TTL is set too low, it may cleanup active spans. The default is currently set to 5 minutes. However, if a span starts and runs for longer than 5 minutes, it will be deleted from the ets table. This does not inherently mean your span cannot be sent still. If it is still the currently active span and does not require a parent, then it will send fine. However, if your span does have a parent older than 5 minutes, it's entirely probable you will end up with an incomplete trace.","ref":"HoneylixirTracing.html","title":"HoneylixirTracing","type":"module"},{"doc":"Adds field data to the current span. This function does nothing if there is no currently active span. Any duplicate field names will have their contents replaced. Returns the updated span if one is active, nil otherwise.","ref":"HoneylixirTracing.html#add_field_data/1","title":"HoneylixirTracing.add_field_data/1","type":"function"},{"doc":"Provides a t:Honeylixir.Propagation.t/0 for sharing tracing data between processes. If there is no span currently active, this will return nil .","ref":"HoneylixirTracing.html#current_propagation_context/0","title":"HoneylixirTracing.current_propagation_context/0","type":"function"},{"doc":"Used for manually ending the currently active span. This SHOULD only be used with start_span calls. Any end_span call SHOULD have a corresponding start_span call, though it will not result in an error if there is no active span. The optional previous_span argument is what the currently active span will be set to after the current one is sent.","ref":"HoneylixirTracing.html#end_span/1","title":"HoneylixirTracing.end_span/1","type":"function"},{"doc":"Helper method for sending a link span annotation. Accepts a t:Honeylixir.Propagation.t/0 as the data for what span to link to. If no span is currently active, does nothing and returns nil . Please consider this feature experimental.","ref":"HoneylixirTracing.html#link_to_span/1","title":"HoneylixirTracing.link_to_span/1","type":"function"},{"doc":"Create and send a span to Honeycomb.","ref":"HoneylixirTracing.html#span/2","title":"HoneylixirTracing.span/2","type":"function"},{"doc":"Create and send a span to Honeycomb by optionally propogating tracing context. This form, span/3 , has two possible calling signatures: the first is a non-propogated span with initial fields; the second accepts a propogated trace but no initial fields.","ref":"HoneylixirTracing.html#span/3","title":"HoneylixirTracing.span/3","type":"function"},{"doc":"Create and send a span to Honeycomb by propogating tracing context. Accepts a HoneylixirTracing.Propagation.t/0 for continuing work from another Process's trace.","ref":"HoneylixirTracing.html#span/4","title":"HoneylixirTracing.span/4","type":"function"},{"doc":"Start a span and manage ending it yourself. See start_span/3 .","ref":"HoneylixirTracing.html#start_span/2","title":"HoneylixirTracing.start_span/2","type":"function"},{"doc":"Start a span and manage ending it yourself. Functionally looks and behaves much like the span functions. It accepts some combination of a propagation context, a span name, and a set of fields to start a span. The result is a tuple of :ok and whatever the previous current span was. You can use this in an end_span/1 call to set the current span back to what it used to be. Every usage of start_span MUST have an end_span call or you may end up with unfinished spans or traces or other unexpected and undesirable results, such as a current span that lives longer than it should. If you can, try to store the previous span somewhere you can use to reset the current span. It is recommended you only use this in cases where this is impossible since in those places you could probably use a function in the span family instead. A common example for using this is using :telemetry events as spans when those events only give a duration rather than at least a start time.","ref":"HoneylixirTracing.html#start_span/3","title":"HoneylixirTracing.start_span/3","type":"function"},{"doc":"Create and send a span to Honeycomb.","ref":"HoneylixirTracing.html#t:span_return/0","title":"HoneylixirTracing.span_return/0","type":"type"},{"doc":"A 0 arity function used as the work to be measured by the span.","ref":"HoneylixirTracing.html#t:work_function/0","title":"HoneylixirTracing.work_function/0","type":"type"},{"doc":"Module responsible for enabling trace propagation. Propagation can be used to pass trace information between Processes within the same application or serialized to be sent to other services for distributed tracing.","ref":"HoneylixirTracing.Propagation.html","title":"HoneylixirTracing.Propagation","type":"module"},{"doc":"Provides map of the header key to the propogation context as a string. Sets the Header key to &quot;X-Honeycomb-Trace&quot; in the map. Note that context is given as an empty string for now as trace fields are not supported.","ref":"HoneylixirTracing.Propagation.html#header/1","title":"HoneylixirTracing.Propagation.header/1","type":"function"},{"doc":"Parses out the Honeycomb trace header string. Note that the context is ignored as trace fields are not currently supported. If the parsing fails, nil is returned.","ref":"HoneylixirTracing.Propagation.html#parse_header/1","title":"HoneylixirTracing.Propagation.parse_header/1","type":"function"},{"doc":"Struct used to pass propagation around between Elixir processes. Can also be serialized with Kernel.to_string/1 as it implements String.Chars for use in headers.","ref":"HoneylixirTracing.Propagation.html#t:t/0","title":"HoneylixirTracing.Propagation.t/0","type":"type"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Allow the HoneylixirTracing public API functions accept nil propagation","ref":"changelog.html#0-3-2","title":"Changelog - 0.3.2","type":"extras"},{"doc":"Add setup/3 that accepts a nil propagation header to take some onus off of users","ref":"changelog.html#0-3-1","title":"Changelog - 0.3.1","type":"extras"},{"doc":"Add Reaper for cleaning up ETS table Change context to be not a stack and store data solely in the ETS table. The main trade-off here is that the Process dictionary causes garbage collection so if we start storing lots of spans in a Process, it may accumulate more memory than it needs. Add utility function for sending link type span annotations Add start_span and end_span for manually managed spans","ref":"changelog.html#0-3-0","title":"Changelog - 0.3.0","type":"extras"},{"doc":"Add the ability to add fields to the currently active span Add tests and CI runs Adds HoneylixirTracing.Propagation for sending data between processes and to other services as the &quot;X-Honeycomb-Trace&quot; header","ref":"changelog.html#0-2-0","title":"Changelog - 0.2.0","type":"extras"},{"doc":"This was a barebones release and should absolutely not be used by people in a real setting. That said, it very basically works for creating spans.","ref":"changelog.html#0-1-0","title":"Changelog - 0.1.0","type":"extras"}]